@@ -34,8 +34,8 @@ import (
 	"github.com/google/uuid"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"github.com/substrait-io/substrait-go/v4/expr"
-	"github.com/substrait-io/substrait-go/v4/types"
+	"github.com/substrait-io/substrait-go/v7/expr"
+	"github.com/substrait-io/substrait-go/v7/types"
 )
 
 var (
@@ -486,7 +486,7 @@ func Test_Types(t *testing.T) {
 	tt := []struct {
 		name   string
 		schema func() *arrow.Schema
-		record func(rq *require.Assertions, schema *arrow.Schema) arrow.Record
+		record func(rq *require.Assertions, schema *arrow.Schema) arrow.RecordBatch
 		val    func(rq *require.Assertions) expr.Literal
 	}{
 		{
@@ -500,7 +500,7 @@ func Test_Types(t *testing.T) {
 
 				return arrow.NewSchema([]arrow.Field{field}, nil)
 			},
-			record: func(rq *require.Assertions, schema *arrow.Schema) arrow.Record {
+			record: func(rq *require.Assertions, schema *arrow.Schema) arrow.RecordBatch {
 				b := array.NewTime64Builder(memory.DefaultAllocator, &arrow.Time64Type{Unit: arrow.Nanosecond})
 				defer b.Release()
 
@@ -509,7 +509,7 @@ func Test_Types(t *testing.T) {
 
 				b.AppendValues([]arrow.Time64{t1}, []bool{true})
 
-				return array.NewRecord(schema, []arrow.Array{b.NewArray()}, 1)
+				return array.NewRecordBatch(schema, []arrow.Array{b.NewArray()}, 1)
 			},
 			val: func(rq *require.Assertions) expr.Literal {
 				v, err := arrow.Time64FromString("11:00:00.000000", arrow.Nanosecond)
@@ -518,6 +518,43 @@ func Test_Types(t *testing.T) {
 				return expr.NewPrimitiveLiteral(types.Time(v), true)
 			},
 		},
+		{
+			name: "expect arrow.TIME64 (ns) ok",
+			schema: func() *arrow.Schema {
+				field := arrow.Field{
+					Name:     "col",
+					Type:     &arrow.Time64Type{Unit: arrow.Nanosecond},
+					Nullable: true,
+				}
+
+				return arrow.NewSchema([]arrow.Field{field}, nil)
+			},
+			record: func(rq *require.Assertions, schema *arrow.Schema) arrow.RecordBatch {
+				b := array.NewTime64Builder(memory.DefaultAllocator, &arrow.Time64Type{Unit: arrow.Nanosecond})
+				defer b.Release()
+
+				t1, err := arrow.Time64FromString("10:00:00.000000", arrow.Nanosecond)
+				rq.NoError(err, "Failed to create Time64 value")
+
+				b.AppendValues([]arrow.Time64{t1}, []bool{true})
+
+				return array.NewRecordBatch(schema, []arrow.Array{b.NewArray()}, 1)
+			},
+			val: func(rq *require.Assertions) expr.Literal {
+				v, err := arrow.Time64FromString("11:00:00.000000", arrow.Nanosecond)
+				rq.NoError(err, "Failed to create Time64 value")
+
+				pt := &types.PrecisionTime{
+					Precision: int32(arrow.Nanosecond) * 3,
+					Value:     int64(v),
+				}
+
+				lit, err := expr.NewLiteral(pt, true)
+				rq.NoError(err, "Failed to create literal")
+
+				return lit
+			},
+		},
 		{
 			name: "expect arrow.TIMESTAMP (ns) ok",
 			schema: func() *arrow.Schema {
@@ -529,7 +566,7 @@ func Test_Types(t *testing.T) {
 
 				return arrow.NewSchema([]arrow.Field{field}, nil)
 			},
-			record: func(rq *require.Assertions, schema *arrow.Schema) arrow.Record {
+			record: func(rq *require.Assertions, schema *arrow.Schema) arrow.RecordBatch {
 				b := array.NewTimestampBuilder(memory.DefaultAllocator, &arrow.TimestampType{Unit: arrow.Nanosecond})
 				defer b.Release()
 
@@ -538,7 +575,7 @@ func Test_Types(t *testing.T) {
 
 				b.AppendValues([]arrow.Timestamp{t1}, []bool{true})
 
-				return array.NewRecord(schema, []arrow.Array{b.NewArray()}, 1)
+				return array.NewRecordBatch(schema, []arrow.Array{b.NewArray()}, 1)
 			},
 			val: func(rq *require.Assertions) expr.Literal {
 				v, err := arrow.TimestampFromString("2021-01-01T11:00:00.000000Z", arrow.Microsecond)
@@ -558,7 +595,7 @@ func Test_Types(t *testing.T) {
 
 				return arrow.NewSchema([]arrow.Field{field}, nil)
 			},
-			record: func(rq *require.Assertions, schema *arrow.Schema) arrow.Record {
+			record: func(rq *require.Assertions, schema *arrow.Schema) arrow.RecordBatch {
 				b := array.NewDecimal128Builder(memory.DefaultAllocator, &arrow.Decimal128Type{Precision: 38, Scale: 10})
 				defer b.Release()
 
@@ -567,7 +604,7 @@ func Test_Types(t *testing.T) {
 
 				b.Append(d)
 
-				return array.NewRecord(schema, []arrow.Array{b.NewArray()}, 1)
+				return array.NewRecordBatch(schema, []arrow.Array{b.NewArray()}, 1)
 			},
 			val: func(rq *require.Assertions) expr.Literal {
 				v, p, s, err := expr.DecimalStringToBytes("456.7890123456")
@@ -621,3 +658,148 @@ func Test_Types(t *testing.T) {
 		})
 	}
 }
+
+func TestLargeTypes(t *testing.T) {
+	sc := arrow.NewSchema([]arrow.Field{
+		{Name: "str", Type: arrow.BinaryTypes.LargeString, Nullable: true},
+		{Name: "bin", Type: arrow.BinaryTypes.LargeBinary, Nullable: true},
+	}, nil)
+
+	rec, _, err := array.RecordFromJSON(memory.DefaultAllocator, sc, strings.NewReader(`[
+		{"str": "hello world", "bin": "Zm9vYmFy"}
+	]`))
+	require.NoError(t, err)
+	defer rec.Release()
+
+	dr := compute.NewDatumWithoutOwning(rec)
+
+	t.Run("large_string ref", func(t *testing.T) {
+		bldr := exprs.NewExprBuilder(extSet)
+		require.NoError(t, bldr.SetInputSchema(sc))
+
+		e, err := bldr.FieldRef("str").BuildExpr()
+		require.NoError(t, err, "Failed to build field reference expression")
+
+		ctx := context.Background()
+		result, err := exprs.ExecuteScalarExpression(ctx, sc, e, dr)
+		require.NoError(t, err, "Failed to execute scalar expression")
+		defer result.Release()
+	})
+
+	t.Run("large_binary ref", func(t *testing.T) {
+		bldr := exprs.NewExprBuilder(extSet)
+		require.NoError(t, bldr.SetInputSchema(sc))
+
+		e, err := bldr.FieldRef("bin").BuildExpr()
+		require.NoError(t, err, "Failed to build field reference expression")
+
+		ctx := context.Background()
+		result, err := exprs.ExecuteScalarExpression(ctx, sc, e, dr)
+		require.NoError(t, err, "Failed to execute scalar expression")
+		defer result.Release()
+	})
+}
+
+func TestDecimalFilterLarge(t *testing.T) {
+	t.Parallel()
+
+	tt := []struct {
+		name string
+		n    int
+	}{
+		{
+			name: "arrow.DECIMAL128 - number of records < 33 ok",
+			n:    32,
+		},
+		{
+			name: "arrow.DECIMAL128 - number of records >= 33 panic",
+			n:    33,
+		},
+	}
+
+	for _, tc := range tt {
+		tc := tc
+		t.Run(tc.name, func(t *testing.T) {
+			t.Parallel()
+
+			ctx := context.Background()
+			rq := require.New(t)
+
+			typ := &arrow.Decimal128Type{Precision: 3, Scale: 1}
+			field := arrow.Field{
+				Name:     "col",
+				Type:     typ,
+				Nullable: true,
+			}
+			schema := arrow.NewSchema([]arrow.Field{field}, nil)
+
+			db := array.NewDecimal128Builder(memory.DefaultAllocator, typ)
+			defer db.Release()
+
+			for i := 0; i < tc.n; i++ {
+				d, err := decimal.Decimal128FromFloat(float64(i), 3, 1)
+				rq.NoError(err, "Failed to create Decimal128 value")
+
+				db.Append(d)
+			}
+
+			rec := array.NewRecordBatch(schema, []arrow.Array{db.NewArray()}, int64(tc.n))
+
+			extSet := exprs.GetExtensionIDSet(ctx)
+			builder := exprs.NewExprBuilder(extSet)
+
+			err := builder.SetInputSchema(schema)
+			rq.NoError(err, "Failed to set input schema")
+
+			v, p, s, err := expr.DecimalStringToBytes("10.0")
+			rq.NoError(err, "Failed to convert decimal string to bytes")
+
+			lit, err := expr.NewLiteral(&types.Decimal{
+				Value:     v[:16],
+				Precision: p,
+				Scale:     s,
+			}, true)
+			rq.NoError(err, "Failed to create Decimal128 literal")
+
+			t.Run("array_scalar", func(t *testing.T) {
+				b, err := builder.CallScalar("less", nil,
+					builder.FieldRef("col"),
+					builder.Literal(lit),
+				)
+
+				rq.NoError(err, "Failed to call scalar")
+
+				e, err := b.BuildExpr()
+				rq.NoError(err, "Failed to build expression")
+
+				ctx = exprs.WithExtensionIDSet(ctx, extSet)
+
+				dr := compute.NewDatum(rec)
+				defer dr.Release()
+
+				_, err = exprs.ExecuteScalarExpression(ctx, schema, e, dr)
+				rq.NoError(err, "Failed to execute scalar expression")
+			})
+
+			t.Run("scalar_array", func(t *testing.T) {
+				b, err := builder.CallScalar("less", nil,
+					builder.Literal(lit),
+					builder.FieldRef("col"),
+				)
+
+				rq.NoError(err, "Failed to call scalar")
+
+				e, err := b.BuildExpr()
+				rq.NoError(err, "Failed to build expression")
+
+				ctx = exprs.WithExtensionIDSet(ctx, extSet)
+
+				dr := compute.NewDatum(rec)
+				defer dr.Release()
+
+				_, err = exprs.ExecuteScalarExpression(ctx, schema, e, dr)
+				rq.NoError(err, "Failed to execute scalar expression")
+			})
+		})
+	}
+}
