@@ -280,7 +280,7 @@ func (c *Client) ExecuteIngest(ctx context.Context, rdr array.RecordReader, reqO
 	wr.SetFlightDescriptor(desc)
 
 	for rdr.Next() {
-		rec := rdr.Record()
+		rec := rdr.RecordBatch()
 		err = wr.Write(rec)
 		if err == io.EOF {
 			// gRPC returns io.EOF if the error was generated by the server.
@@ -1223,7 +1223,7 @@ func (p *PreparedStatement) ExecuteUpdate(ctx context.Context, opts ...grpc.Call
 		schema := arrow.NewSchema([]arrow.Field{}, nil)
 		wr = flight.NewRecordWriter(pstream, ipc.WithSchema(schema))
 		wr.SetFlightDescriptor(desc)
-		rec := array.NewRecord(schema, []arrow.Array{}, 0)
+		rec := array.NewRecordBatch(schema, []arrow.Array{}, 0)
 		if err = wr.Write(rec); err != nil {
 			return
 		}
@@ -1291,7 +1291,7 @@ func (p *PreparedStatement) writeBindParametersToStream(pstream pb.FlightService
 		wr := flight.NewRecordWriter(pstream, ipc.WithSchema(p.streamBinding.Schema()))
 		wr.SetFlightDescriptor(desc)
 		for p.streamBinding.Next() {
-			if err := wr.Write(p.streamBinding.Record()); err != nil {
+			if err := wr.Write(p.streamBinding.RecordBatch()); err != nil {
 				return nil, err
 			}
 		}
