@@ -44,7 +44,7 @@ type SqliteTablesSchemaBatchReader struct {
 	rdr        array.RecordReader
 	stmt       *sql.Stmt
 	schemaBldr *array.BinaryBuilder
-	record     arrow.Record
+	record     arrow.RecordBatch
 	err        error
 }
 
@@ -94,7 +94,10 @@ func (s *SqliteTablesSchemaBatchReader) Schema() *arrow.Schema {
 	return arrow.NewSchema(fields, nil)
 }
 
-func (s *SqliteTablesSchemaBatchReader) Record() arrow.Record { return s.record }
+func (s *SqliteTablesSchemaBatchReader) RecordBatch() arrow.RecordBatch { return s.record }
+
+// Deprecated: Use [RecordBatch] instead.
+func (s *SqliteTablesSchemaBatchReader) Record() arrow.Record { return s.RecordBatch() }
 
 func getSqlTypeFromTypeName(sqltype string) int {
 	if sqltype == "" {
@@ -157,7 +160,7 @@ func (s *SqliteTablesSchemaBatchReader) Next() bool {
 		return false
 	}
 
-	rec := s.rdr.Record()
+	rec := s.rdr.RecordBatch()
 	tableNameArr := rec.Column(rec.Schema().FieldIndices("table_name")[0]).(*array.String)
 
 	bldr := flightsql.NewColumnMetadataBuilder()
@@ -203,6 +206,6 @@ func (s *SqliteTablesSchemaBatchReader) Next() bool {
 	schemaCol := s.schemaBldr.NewArray()
 	defer schemaCol.Release()
 
-	s.record = array.NewRecord(s.Schema(), append(rec.Columns(), schemaCol), rec.NumRows())
+	s.record = array.NewRecordBatch(s.Schema(), append(rec.Columns(), schemaCol), rec.NumRows())
 	return true
 }
