@@ -18,6 +18,7 @@ package file_test
 
 import (
 	"bytes"
+	"errors"
 	"math"
 	"reflect"
 	"runtime"
@@ -79,6 +80,9 @@ func (m *mockpagewriter) Compress(buf *bytes.Buffer, src []byte) []byte {
 func (m *mockpagewriter) Reset(sink utils.WriterTell, codec compress.Compression, compressionLevel int, metadata *metadata.ColumnChunkMetaDataBuilder, rgOrdinal, columnOrdinal int16, metaEncryptor, dataEncryptor encryption.Encryptor) error {
 	return m.Called().Error(0)
 }
+func (m *mockpagewriter) SetIndexBuilders(colidx metadata.ColumnIndexBuilder, offsetidx *metadata.OffsetIndexBuilder) {
+	m.Called(colidx, offsetidx)
+}
 
 func TestWriteDataPageV1NumValues(t *testing.T) {
 	sc := schema.NewSchema(schema.MustGroup(schema.NewGroupNode("schema", parquet.Repetitions.Required, schema.FieldList{
@@ -255,7 +259,7 @@ func (p *PrimitiveWriterTestSuite) TearDownTest() {
 
 func (p *PrimitiveWriterTestSuite) buildReader(nrows int64, compression compress.Compression) file.ColumnChunkReader {
 	p.readbuffer = p.sink.Finish()
-	pagereader, _ := file.NewPageReader(arrutils.NewBufferedReader(bytes.NewReader(p.readbuffer.Bytes()), p.readbuffer.Len()), nrows, compression, mem, nil)
+	pagereader, _ := file.NewPageReader(arrutils.NewByteReader(p.readbuffer.Bytes()), nrows, compression, mem, nil)
 	return file.NewColumnReader(p.descr, pagereader, mem, &p.bufferPool)
 }
 
@@ -288,12 +292,41 @@ func (p *PrimitiveWriterTestSuite) readColumnFully(compression compress.Compress
 		read := p.ReadBatch(reader, totalValues-valuesRead, valuesRead, p.DefLevelsOut[valuesRead:], p.RepLevelsOut[valuesRead:])
 		valuesRead += read
 	}
+	p.NoError(reader.Close())
 	return valuesRead
 }
 
+// checkReadColumnByPage is used to check the data read from two interface is same
+func (p *PrimitiveWriterTestSuite) checkReadColumnByPage(compression compress.Compression) {
+	if p.descr.PhysicalType() != parquet.Types.FixedLenByteArray && p.descr.PhysicalType() != parquet.Types.ByteArray {
+		return
+	}
+	totalValues := int64(len(p.DefLevelsOut))
+	pagereader, _ := file.NewPageReader(arrutils.NewByteReader(p.readbuffer.Bytes()), totalValues, compression, mem, nil)
+	reader := file.NewColumnReader(p.descr, pagereader, mem, &p.bufferPool)
+
+	valuesRead := int64(0)
+	for valuesRead < totalValues {
+		read := p.ReadBatchInPage(reader, totalValues-valuesRead, p.DefLevelsOut, p.RepLevelsOut)
+		switch reader.(type) {
+		case *file.ByteArrayColumnChunkReader:
+			batchOut := p.ValuesOut.([]parquet.ByteArray)
+			pageOut := p.ValuesOutPage.([]parquet.ByteArray)
+			p.Equal(batchOut[valuesRead:valuesRead+read], pageOut[:read])
+		case *file.FixedLenByteArrayColumnChunkReader:
+			batchOut := p.ValuesOut.([]parquet.FixedLenByteArray)
+			pageOut := p.ValuesOutPage.([]parquet.FixedLenByteArray)
+			p.Equal(batchOut[valuesRead:valuesRead+read], pageOut[:read])
+		}
+		valuesRead += read
+	}
+	p.NoError(reader.Close())
+}
+
 func (p *PrimitiveWriterTestSuite) readAndCompare(compression compress.Compression, nrows int64) {
 	p.SetupValuesOut(nrows)
 	p.readColumnFully(compression)
+	p.checkReadColumnByPage(compression)
 	p.Equal(p.Values, p.ValuesOut)
 }
 
@@ -390,6 +423,7 @@ func (p *PrimitiveWriterTestSuite) testDictionaryFallbackEncoding(version parque
 	// Read all the rows so that we are sure that also the non-dictionary pages are read correctly
 	p.SetupValuesOut(VeryLargeSize)
 	valuesRead := p.readColumnFully(compress.Codecs.Uncompressed)
+	p.checkReadColumnByPage(compress.Codecs.Uncompressed)
 	p.EqualValues(VeryLargeSize, valuesRead)
 	p.Equal(p.Values, p.ValuesOut)
 
@@ -779,7 +813,7 @@ func TestDictionaryReslice(t *testing.T) {
 			for i := 0; i < 2000; i++ {
 				b.Field(0).(*array.BinaryDictionaryBuilder).AppendString("test_value")
 			}
-			rec := b.NewRecord()
+			rec := b.NewRecordBatch()
 			out := &bytes.Buffer{}
 			pqw, err := pqarrow.NewFileWriter(rec.Schema(), out, nil, pqarrow.NewArrowWriterProperties())
 			assert.NoError(t, err)
@@ -789,3 +823,42 @@ func TestDictionaryReslice(t *testing.T) {
 		})
 	}
 }
+
+// TestWriteDataFailure asserts that if WriteDataPage fails, the internal state of the
+// ColumnChunkWriter is still valid and accessing function does not panic.
+func TestWriteDataFailure(t *testing.T) {
+	sc := schema.NewSchema(schema.MustGroup(schema.NewGroupNode("schema", parquet.Repetitions.Required, schema.FieldList{
+		schema.Must(schema.ListOf(
+			schema.Must(schema.NewPrimitiveNode("column", parquet.Repetitions.Optional, parquet.Types.Int32, -1, -1)),
+			parquet.Repetitions.Optional, -1)),
+	}, -1)))
+	descr := sc.Column(0)
+	props := parquet.NewWriterProperties(
+		parquet.WithStats(true),
+		parquet.WithVersion(parquet.V1_0),
+		parquet.WithDataPageVersion(parquet.DataPageV1),
+		parquet.WithDictionaryDefault(true)) // true to enable buffering pages.
+
+	metadata := metadata.NewColumnChunkMetaDataBuilder(props, descr)
+	pager := new(mockpagewriter)
+	defer pager.AssertExpectations(t)
+	pager.On("HasCompressor").Return(false)
+	wr := file.NewColumnChunkWriter(metadata, pager, props).(*file.Int32ColumnChunkWriter)
+
+	// Write some valid data.
+	wr.WriteBatch([]int32{0, 1, 2, 3},
+		[]int16{3, 3, 0, 3, 2, 3},
+		[]int16{0, 1, 0, 0, 1, 1})
+
+	// Simulate WriteDataPage failure.
+	failureErr := errors.New("mock error from WriteDataPage")
+	pager.On("WriteDataPage", mock.MatchedBy(func(page file.DataPage) bool {
+		_, ok := page.(*file.DataPageV1)
+		return ok
+	})).Return(0, failureErr)
+
+	// Expect error from FlushBufferedDataPages but it should leave internal fields in valid state.
+	err := wr.FlushBufferedDataPages()
+	assert.Equal(t, err, failureErr)
+	assert.Equal(t, int64(0), wr.TotalBytesWritten())
+}
