@@ -18,12 +18,14 @@ package file
 
 import (
 	"bytes"
+	"errors"
 	"fmt"
 	"io"
+	"sort"
 	"sync"
 
-	"github.com/JohnCGriffin/overflow"
 	"github.com/apache/arrow-go/v18/arrow/memory"
+	"github.com/apache/arrow-go/v18/internal/utils"
 	"github.com/apache/arrow-go/v18/parquet"
 	"github.com/apache/arrow-go/v18/parquet/compress"
 	"github.com/apache/arrow-go/v18/parquet/internal/encryption"
@@ -47,12 +49,27 @@ type PageReader interface {
 	Err() error
 	// Reset allows reusing a page reader
 	Reset(r parquet.BufferedReader, nrows int64, compressType compress.Compression, ctx *CryptoContext)
+
+	// Get the dictionary page for this column chunk
+	GetDictionaryPage() (*DictionaryPage, error)
+	SeekToPageWithRow(rowIdx int64) error
+	// Close releases the resources held by the reader.
+	Close() error
 }
 
+type PageType = format.PageType
+
+const (
+	PageTypeDataPage       PageType = format.PageType_DATA_PAGE
+	PageTypeDataPageV2     PageType = format.PageType_DATA_PAGE_V2
+	PageTypeDictionaryPage PageType = format.PageType_DICTIONARY_PAGE
+	PageTypeIndexPage      PageType = format.PageType_INDEX_PAGE
+)
+
 // Page is an interface for handling DataPages or Dictionary Pages
 type Page interface {
 	// Returns which kind of page this is
-	Type() format.PageType
+	Type() PageType
 	// Get the raw bytes of this page
 	Data() []byte
 	// return the encoding used for this page, Plain/RLE, etc.
@@ -71,17 +88,31 @@ type page struct {
 	encoding format.Encoding
 }
 
-func (p *page) Type() format.PageType     { return p.typ }
+func (p *page) Type() PageType            { return p.typ }
 func (p *page) Data() []byte              { return p.buf.Bytes() }
 func (p *page) NumValues() int32          { return p.nvals }
 func (p *page) Encoding() format.Encoding { return p.encoding }
 
+// DataPageConfig is a struct for passing configuration params to data page creation
+// which can be expanded in the future without causing any breaking changes.
+type DataPageConfig struct {
+	Num              int32
+	Encoding         parquet.Encoding
+	UncompressedSize int32
+	Stats            metadata.EncodedStatistics
+	FirstRowIndex    int64
+	SizeStats        SizeStatistics
+}
+
 // DataPage is the base interface for both DataPageV1 and DataPageV2 of the
 // parquet spec.
 type DataPage interface {
 	Page
 	UncompressedSize() int32
 	Statistics() metadata.EncodedStatistics
+	// FirstRowIndex returns the row ordinal within the row group
+	// to the first row in the data page, or -1 if not set.
+	FirstRowIndex() int64
 }
 
 // Create some pools to use for reusing the data page objects themselves so that
@@ -110,6 +141,8 @@ type DataPageV1 struct {
 	repLvlEncoding   format.Encoding
 	uncompressedSize int32
 	statistics       metadata.EncodedStatistics
+	firstRowIndex    int64
+	sizeStatistics   SizeStatistics
 }
 
 // NewDataPageV1 returns a V1 data page with the given buffer as its data and the specified encoding information
@@ -125,6 +158,7 @@ func NewDataPageV1(buffer *memory.Buffer, num int32, encoding, defEncoding, repE
 			defLvlEncoding:   format.Encoding(defEncoding),
 			repLvlEncoding:   format.Encoding(repEncoding),
 			uncompressedSize: uncompressedSize,
+			firstRowIndex:    -1,
 		}
 	}
 
@@ -134,6 +168,8 @@ func NewDataPageV1(buffer *memory.Buffer, num int32, encoding, defEncoding, repE
 	dp.statistics.HasMax, dp.statistics.HasMin = false, false
 	dp.statistics.HasNullCount, dp.statistics.HasDistinctCount = false, false
 	dp.uncompressedSize = uncompressedSize
+	dp.firstRowIndex = -1
+	dp.sizeStatistics = SizeStatistics{}
 	return dp
 }
 
@@ -144,6 +180,14 @@ func NewDataPageV1WithStats(buffer *memory.Buffer, num int32, encoding, defEncod
 	return ret
 }
 
+// NewDataPageV1WithConfig uses a DataPageConfig object to encapsulate some parameters for future expansion
+// rather than continuing to add new functions to the API to avoid breaking changes.
+func NewDataPageV1WithConfig(buffer *memory.Buffer, defEncoding, repEncoding parquet.Encoding, cfg DataPageConfig) *DataPageV1 {
+	ret := NewDataPageV1WithStats(buffer, cfg.Num, cfg.Encoding, defEncoding, repEncoding, cfg.UncompressedSize, cfg.Stats)
+	ret.firstRowIndex, ret.sizeStatistics = cfg.FirstRowIndex, cfg.SizeStats
+	return ret
+}
+
 // Release this page back into the DataPage object pool so that it can be reused.
 //
 // After calling this function, the object should not be utilized anymore, otherwise
@@ -154,6 +198,8 @@ func (d *DataPageV1) Release() {
 	dataPageV1Pool.Put(d)
 }
 
+func (d *DataPageV1) FirstRowIndex() int64 { return d.firstRowIndex }
+
 // UncompressedSize returns the size of the data in this data page when uncompressed
 func (d *DataPageV1) UncompressedSize() int32 { return d.uncompressedSize }
 
@@ -181,6 +227,8 @@ type DataPageV2 struct {
 	compressed       bool
 	uncompressedSize int32
 	statistics       metadata.EncodedStatistics
+	firstRowIndex    int64
+	sizeStatistics   SizeStatistics
 }
 
 // NewDataPageV2 constructs a new V2 data page with the provided information and a buffer of the raw data.
@@ -195,6 +243,7 @@ func NewDataPageV2(buffer *memory.Buffer, numValues, numNulls, numRows int32, en
 			repLvlByteLen:    repLvlsByteLen,
 			compressed:       isCompressed,
 			uncompressedSize: uncompressed,
+			firstRowIndex:    -1,
 		}
 	}
 
@@ -205,6 +254,8 @@ func NewDataPageV2(buffer *memory.Buffer, numValues, numNulls, numRows int32, en
 	dp.compressed, dp.uncompressedSize = isCompressed, uncompressed
 	dp.statistics.HasMax, dp.statistics.HasMin = false, false
 	dp.statistics.HasNullCount, dp.statistics.HasDistinctCount = false, false
+	dp.firstRowIndex = -1
+	dp.sizeStatistics = SizeStatistics{}
 	return dp
 }
 
@@ -215,6 +266,14 @@ func NewDataPageV2WithStats(buffer *memory.Buffer, numValues, numNulls, numRows
 	return ret
 }
 
+// NewDataPageV2WithConfig uses a DataPageConfig object to encapsulate some parameters for future expansion
+// rather than continuing to add new functions to the API to avoid breaking changes.
+func NewDataPageV2WithConfig(buffer *memory.Buffer, numNulls, numRows int32, defLvlsByteLen, repLvlsByteLen int32, isCompressed bool, cfg DataPageConfig) *DataPageV2 {
+	ret := NewDataPageV2WithStats(buffer, cfg.Num, numNulls, numRows, cfg.Encoding, defLvlsByteLen, repLvlsByteLen, cfg.UncompressedSize, isCompressed, cfg.Stats)
+	ret.firstRowIndex, ret.sizeStatistics = cfg.FirstRowIndex, cfg.SizeStats
+	return ret
+}
+
 // Release this page back into the DataPage object pool so that it can be reused.
 //
 // After calling this function, the object should not be utilized anymore, otherwise
@@ -225,6 +284,8 @@ func (d *DataPageV2) Release() {
 	dataPageV2Pool.Put(d)
 }
 
+func (d *DataPageV2) FirstRowIndex() int64 { return d.firstRowIndex }
+
 // UncompressedSize is the size of the raw page when uncompressed. If `IsCompressed` is true, then
 // the raw data in the buffer is expected to be compressed.
 func (d *DataPageV2) UncompressedSize() int32 { return d.uncompressedSize }
@@ -289,7 +350,11 @@ func (d *DictionaryPage) Release() {
 func (d *DictionaryPage) IsSorted() bool { return d.sorted }
 
 type serializedPageReader struct {
-	r        parquet.BufferedReader
+	r             parquet.BufferedReader
+	chunk         *metadata.ColumnChunkMetaData
+	colIdx        int
+	pgIndexReader *metadata.RowGroupPageIndexReader
+
 	nrows    int64
 	rowsSeen int64
 	mem      memory.Allocator
@@ -304,11 +369,57 @@ type serializedPageReader struct {
 	dataPageAad       string
 	dataPageHeaderAad string
 
-	decompressBuffer bytes.Buffer
+	baseOffset, dataOffset, dictOffset int64
+
+	decompressBuffer *memory.Buffer
+	dataPageBuffer   *memory.Buffer
+	dictPageBuffer   *memory.Buffer
 	err              error
 }
 
+func (p *serializedPageReader) Close() error {
+	if p.decompressBuffer != nil {
+		p.decompressBuffer.Release()
+		p.dictPageBuffer.Release()
+		p.dataPageBuffer.Release()
+	}
+	return nil
+}
+
+func (p *serializedPageReader) init(compressType compress.Compression, ctx *CryptoContext) error {
+	if p.mem == nil {
+		p.mem = memory.NewGoAllocator()
+	}
+	p.decompressBuffer = memory.NewResizableBuffer(p.mem)
+	p.dataPageBuffer = memory.NewResizableBuffer(p.mem)
+	p.dictPageBuffer = memory.NewResizableBuffer(p.mem)
+	p.decompressBuffer.ResizeNoShrink(defaultPageHeaderSize)
+
+	codec, err := compress.GetCodec(compressType)
+	if err != nil {
+		return err
+	}
+	p.codec = codec
+
+	if ctx != nil {
+		p.cryptoCtx = *ctx
+		p.initDecryption()
+	}
+
+	p.baseOffset = p.chunk.DataPageOffset()
+	p.dataOffset = p.baseOffset
+	if p.chunk.HasDictionaryPage() && p.chunk.DictionaryPageOffset() > 0 {
+		p.baseOffset = p.chunk.DictionaryPageOffset()
+		p.dictOffset = p.baseOffset
+	}
+
+	return nil
+}
+
 // NewPageReader returns a page reader for the data which can be read from the provided reader and compression.
+//
+// Deprecated: This function isn't properly safe for public API use and should not be utilized
+// anymore. It will be removed from the public interface soon to prevent usage outside of this package.
 func NewPageReader(r parquet.BufferedReader, nrows int64, compressType compress.Compression, mem memory.Allocator, ctx *CryptoContext) (PageReader, error) {
 	if mem == nil {
 		mem = memory.NewGoAllocator()
@@ -325,8 +436,12 @@ func NewPageReader(r parquet.BufferedReader, nrows int64, compressType compress.
 		nrows:             nrows,
 		mem:               mem,
 		codec:             codec,
+
+		decompressBuffer: memory.NewResizableBuffer(mem),
+		dataPageBuffer:   memory.NewResizableBuffer(mem),
+		dictPageBuffer:   memory.NewResizableBuffer(mem),
 	}
-	rdr.decompressBuffer.Grow(defaultPageHeaderSize)
+	rdr.decompressBuffer.ResizeNoShrink(defaultPageHeaderSize)
 	if ctx != nil {
 		rdr.cryptoCtx = *ctx
 		rdr.initDecryption()
@@ -343,7 +458,6 @@ func (p *serializedPageReader) Reset(r parquet.BufferedReader, nrows int64, comp
 	if p.err != nil {
 		return
 	}
-	p.decompressBuffer.Reset()
 	if ctx != nil {
 		p.cryptoCtx = *ctx
 		p.initDecryption()
@@ -386,9 +500,10 @@ func (p *serializedPageReader) Page() Page {
 	return p.curPage
 }
 
-func (p *serializedPageReader) decompress(lenCompressed int, buf []byte) ([]byte, error) {
-	p.decompressBuffer.Grow(lenCompressed)
-	if _, err := io.CopyN(&p.decompressBuffer, p.r, int64(lenCompressed)); err != nil {
+func (p *serializedPageReader) decompress(rd io.Reader, lenCompressed int, buf []byte) ([]byte, error) {
+	p.decompressBuffer.ResizeNoShrink(lenCompressed)
+	b := bytes.NewBuffer(p.decompressBuffer.Bytes()[:0])
+	if _, err := io.CopyN(b, rd, int64(lenCompressed)); err != nil {
 		return nil, err
 	}
 
@@ -429,6 +544,148 @@ func extractStats(dataHeader dataheader) (pageStats metadata.EncodedStatistics)
 	return
 }
 
+func (p *serializedPageReader) GetDictionaryPage() (*DictionaryPage, error) {
+	if p.dictOffset > 0 {
+		hdr := format.NewPageHeader()
+		readBufSize := min(int(p.dataOffset-p.baseOffset), p.r.BufferSize())
+		rd := utils.NewBufferedReader(
+			io.NewSectionReader(p.r.Outer(), p.dictOffset-p.baseOffset, p.dataOffset-p.baseOffset),
+			readBufSize)
+		if err := p.readPageHeader(rd, hdr); err != nil {
+			return nil, err
+		}
+
+		dictHeader := hdr.GetDictionaryPageHeader()
+		if dictHeader == nil {
+			return nil, errors.New("parquet: invalid dictionary page header")
+		}
+
+		p.cryptoCtx.StartDecryptWithDictionaryPage = true
+		if p.cryptoCtx.DataDecryptor != nil {
+			p.updateDecryption(p.cryptoCtx.DataDecryptor, encryption.DictPageModule, p.dataPageAad)
+		}
+
+		lenCompressed := int(hdr.GetCompressedPageSize())
+		lenUncompressed := int(hdr.GetUncompressedPageSize())
+		if lenCompressed < 0 || lenUncompressed < 0 {
+			return nil, errors.New("parquet: invalid page header")
+		}
+
+		p.cryptoCtx.StartDecryptWithDictionaryPage = false
+		if dictHeader.GetNumValues() < 0 {
+			return nil, errors.New("parquet: invalid page header (negative number of values)")
+		}
+
+		p.dictPageBuffer.ResizeNoShrink(lenUncompressed)
+		buf := memory.NewBufferBytes(p.dictPageBuffer.Bytes())
+
+		data, err := p.decompress(rd, lenCompressed, buf.Bytes())
+		if err != nil {
+			return nil, err
+		}
+		if len(data) != lenUncompressed {
+			return nil, fmt.Errorf("parquet: metadata said %d bytes uncompressed dictionary page, got %d bytes", lenUncompressed, len(data))
+		}
+
+		return &DictionaryPage{
+			page: page{
+				buf:      buf,
+				typ:      hdr.Type,
+				nvals:    dictHeader.GetNumValues(),
+				encoding: dictHeader.GetEncoding(),
+			},
+			sorted: dictHeader.IsSetIsSorted() && dictHeader.GetIsSorted(),
+		}, nil
+	}
+
+	return nil, nil
+}
+
+func (p *serializedPageReader) readPageHeader(rd parquet.BufferedReader, hdr *format.PageHeader) error {
+	allowedPgSz := defaultPageHeaderSize
+	for {
+		view, err := rd.Peek(allowedPgSz)
+		if err != nil && err != io.EOF {
+			return err
+		}
+
+		if len(view) == 0 {
+			return io.EOF
+		}
+
+		extra := 0
+		if p.cryptoCtx.MetaDecryptor != nil {
+			p.updateDecryption(p.cryptoCtx.MetaDecryptor, encryption.DictPageHeaderModule, p.dataPageHeaderAad)
+			view = p.cryptoCtx.MetaDecryptor.Decrypt(view)
+			extra = p.cryptoCtx.MetaDecryptor.CiphertextSizeDelta()
+		}
+
+		remaining, err := thrift.DeserializeThrift(hdr, view)
+		if err != nil {
+			allowedPgSz *= 2
+			if allowedPgSz > p.maxPageHeaderSize {
+				return errors.New("parquet: deserializing page header failed")
+			}
+			continue
+		}
+
+		rd.Discard(len(view) - int(remaining) + extra)
+		break
+	}
+	return nil
+}
+
+func (p *serializedPageReader) SeekToPageWithRow(rowIdx int64) error {
+	if rowIdx < 0 || rowIdx >= p.nrows {
+		return fmt.Errorf("parquet: cannot seek column reader to row index %d", rowIdx)
+	}
+
+	var (
+		oidx metadata.OffsetIndex
+		err  error
+	)
+
+	if p.pgIndexReader != nil {
+		oidx, err = p.pgIndexReader.GetOffsetIndex(p.colIdx)
+		if err != nil {
+			return err
+		}
+	}
+
+	section := p.r.Outer()
+	if oidx == nil {
+		if _, err = section.Seek(p.dataOffset-p.baseOffset, io.SeekStart); err != nil {
+			return err
+		}
+		p.r.Reset(section)
+
+		p.rowsSeen = 0
+		p.pageOrd = 0
+
+		for p.Next() && p.rowsSeen < rowIdx {
+		}
+		return p.err
+	}
+
+	pages := oidx.GetPageLocations()
+	index := sort.Search(len(pages), func(i int) bool {
+		return pages[i].FirstRowIndex > rowIdx
+	}) - 1
+
+	if index < 0 {
+		return fmt.Errorf("parquet: seek out of range")
+	}
+
+	if _, err = section.Seek(pages[index].GetOffset()-p.baseOffset, io.SeekStart); err != nil {
+		return err
+	}
+
+	p.r.Reset(section)
+	p.rowsSeen, p.pageOrd = pages[index].FirstRowIndex, int16(index)
+	p.Next()
+	return p.err
+}
+
 func (p *serializedPageReader) Next() bool {
 	// Loop here because there may be unhandled page types that we skip until
 	// finding a page that we do know what to do with
@@ -440,44 +697,18 @@ func (p *serializedPageReader) Next() bool {
 	p.err = nil
 
 	for p.rowsSeen < p.nrows {
-		allowedPgSz := defaultPageHeaderSize
-		p.decompressBuffer.Reset()
-		for {
-			view, err := p.r.Peek(allowedPgSz)
-			if err != nil && err != io.EOF {
+		if err := p.readPageHeader(p.r, p.curPageHdr); err != nil {
+			if err != io.EOF {
 				p.err = err
-				return false
 			}
 
-			if len(view) == 0 {
-				return false
-			}
-
-			extra := 0
-			if p.cryptoCtx.MetaDecryptor != nil {
-				p.updateDecryption(p.cryptoCtx.MetaDecryptor, encryption.DictPageHeaderModule, p.dataPageHeaderAad)
-				view = p.cryptoCtx.MetaDecryptor.Decrypt(view)
-				extra = p.cryptoCtx.MetaDecryptor.CiphertextSizeDelta()
-			}
-
-			remaining, err := thrift.DeserializeThrift(p.curPageHdr, view)
-			if err != nil {
-				allowedPgSz *= 2
-				if allowedPgSz > p.maxPageHeaderSize {
-					p.err = xerrors.New("parquet: deserializing page header failed")
-					return false
-				}
-				continue
-			}
-
-			p.r.Discard(len(view) - int(remaining) + extra)
-			break
+			return false
 		}
 
 		lenCompressed := int(p.curPageHdr.GetCompressedPageSize())
 		lenUncompressed := int(p.curPageHdr.GetUncompressedPageSize())
 		if lenCompressed < 0 || lenUncompressed < 0 {
-			p.err = xerrors.New("parquet: invalid page header")
+			p.err = errors.New("parquet: invalid page header")
 			return false
 		}
 
@@ -485,10 +716,6 @@ func (p *serializedPageReader) Next() bool {
 			p.updateDecryption(p.cryptoCtx.DataDecryptor, encryption.DictPageModule, p.dataPageAad)
 		}
 
-		buf := memory.NewResizableBuffer(p.mem)
-		defer buf.Release()
-		buf.ResizeNoShrink(lenUncompressed)
-
 		switch p.curPageHdr.GetType() {
 		case format.PageType_DICTIONARY_PAGE:
 			p.cryptoCtx.StartDecryptWithDictionaryPage = false
@@ -498,7 +725,10 @@ func (p *serializedPageReader) Next() bool {
 				return false
 			}
 
-			data, err := p.decompress(lenCompressed, buf.Bytes())
+			p.dictPageBuffer.ResizeNoShrink(lenUncompressed)
+			buf := memory.NewBufferBytes(p.dictPageBuffer.Bytes())
+
+			data, err := p.decompress(p.r, lenCompressed, buf.Bytes())
 			if err != nil {
 				p.err = err
 				return false
@@ -511,7 +741,7 @@ func (p *serializedPageReader) Next() bool {
 			// make dictionary page
 			p.curPage = &DictionaryPage{
 				page: page{
-					buf:      memory.NewBufferBytes(data),
+					buf:      buf,
 					typ:      p.curPageHdr.Type,
 					nvals:    dictHeader.GetNumValues(),
 					encoding: dictHeader.GetEncoding(),
@@ -527,8 +757,12 @@ func (p *serializedPageReader) Next() bool {
 				return false
 			}
 
+			p.dataPageBuffer.ResizeNoShrink(lenUncompressed)
+			buf := memory.NewBufferBytes(p.dataPageBuffer.Bytes())
+
+			firstRowIdx := p.rowsSeen
 			p.rowsSeen += int64(dataHeader.GetNumValues())
-			data, err := p.decompress(lenCompressed, buf.Bytes())
+			data, err := p.decompress(p.r, lenCompressed, buf.Bytes())
 			if err != nil {
 				p.err = err
 				return false
@@ -541,7 +775,7 @@ func (p *serializedPageReader) Next() bool {
 			// make datapagev1
 			p.curPage = &DataPageV1{
 				page: page{
-					buf:      memory.NewBufferBytes(data),
+					buf:      buf,
 					typ:      p.curPageHdr.Type,
 					nvals:    dataHeader.GetNumValues(),
 					encoding: dataHeader.GetEncoding(),
@@ -550,6 +784,7 @@ func (p *serializedPageReader) Next() bool {
 				repLvlEncoding:   dataHeader.GetRepetitionLevelEncoding(),
 				uncompressedSize: int32(lenUncompressed),
 				statistics:       extractStats(dataHeader),
+				firstRowIndex:    firstRowIdx,
 			}
 		case format.PageType_DATA_PAGE_V2:
 			p.pageOrd++
@@ -564,10 +799,14 @@ func (p *serializedPageReader) Next() bool {
 				return false
 			}
 
+			p.dataPageBuffer.ResizeNoShrink(lenUncompressed)
+			buf := memory.NewBufferBytes(p.dataPageBuffer.Bytes())
+
 			compressed := dataHeader.GetIsCompressed()
 			// extract stats
-			p.rowsSeen += int64(dataHeader.GetNumValues())
-			levelsBytelen, ok := overflow.Add(int(dataHeader.GetDefinitionLevelsByteLength()), int(dataHeader.GetRepetitionLevelsByteLength()))
+			firstRowIdx := p.rowsSeen
+			p.rowsSeen += int64(dataHeader.GetNumRows())
+			levelsBytelen, ok := utils.Add(int(dataHeader.GetDefinitionLevelsByteLength()), int(dataHeader.GetRepetitionLevelsByteLength()))
 			if !ok {
 				p.err = xerrors.New("parquet: levels size too large (corrupt file?)")
 				return false
@@ -577,13 +816,12 @@ func (p *serializedPageReader) Next() bool {
 				if levelsBytelen > 0 {
 					io.ReadFull(p.r, buf.Bytes()[:levelsBytelen])
 				}
-				if _, p.err = p.decompress(lenCompressed-levelsBytelen, buf.Bytes()[levelsBytelen:]); p.err != nil {
+				if _, p.err = p.decompress(p.r, lenCompressed-levelsBytelen, buf.Bytes()[levelsBytelen:]); p.err != nil {
 					return false
 				}
 			} else {
 				io.ReadFull(p.r, buf.Bytes())
 			}
-			buf.Retain()
 
 			if buf.Len() != lenUncompressed {
 				p.err = fmt.Errorf("parquet: metadata said %d bytes uncompressed data page, got %d bytes", lenUncompressed, buf.Len())
@@ -605,11 +843,13 @@ func (p *serializedPageReader) Next() bool {
 				compressed:       compressed,
 				uncompressedSize: int32(lenUncompressed),
 				statistics:       extractStats(dataHeader),
+				firstRowIndex:    firstRowIdx,
 			}
 		default:
 			// we don't know this page type, we're allowed to skip non-data pages
 			continue
 		}
+
 		return true
 	}
 
