@@ -19,6 +19,7 @@ package metadata
 import (
 	"bytes"
 	"context"
+	"crypto/subtle"
 	"fmt"
 	"io"
 	"reflect"
@@ -47,6 +48,7 @@ type FileMetaDataBuilder struct {
 	currentRgBldr  *RowGroupMetaDataBuilder
 	kvmeta         KeyValueMetadata
 	cryptoMetadata *format.FileCryptoMetaData
+	fileEncryptor  encryption.FileEncryptor
 }
 
 // NewFileMetadataBuilder will use the default writer properties if nil is passed for
@@ -65,6 +67,10 @@ func NewFileMetadataBuilder(schema *schema.Schema, props *parquet.WriterProperti
 	}
 }
 
+func (f *FileMetaDataBuilder) SetFileEncryptor(encryptor encryption.FileEncryptor) {
+	f.fileEncryptor = encryptor
+}
+
 // GetFileCryptoMetaData returns the cryptographic information for encrypting/
 // decrypting the file.
 func (f *FileMetaDataBuilder) GetFileCryptoMetaData() *FileCryptoMetadata {
@@ -92,6 +98,7 @@ func (f *FileMetaDataBuilder) AppendRowGroup() *RowGroupMetaDataBuilder {
 	rg := format.NewRowGroup()
 	f.rowGroups = append(f.rowGroups, rg)
 	f.currentRgBldr = NewRowGroupMetaDataBuilder(f.props, f.schema, rg)
+	f.currentRgBldr.fileEncryptor = f.fileEncryptor
 	return f.currentRgBldr
 }
 
@@ -173,6 +180,42 @@ func (f *FileMetaDataBuilder) Snapshot() (*FileMetaData, error) {
 	return out, nil
 }
 
+func (f *FileMetaDataBuilder) SetPageIndexLocation(loc PageIndexLocation) error {
+	setIndexLoc := func(rgOrdinal int64, fileIdxLoc map[uint64][]*IndexLocation, colIndex bool) error {
+		rgMeta := f.rowGroups[rgOrdinal]
+		iter, ok := fileIdxLoc[uint64(rgOrdinal)]
+		if ok {
+			for i, idxLoc := range iter {
+				if i >= len(rgMeta.Columns) {
+					return fmt.Errorf("cannot find metadata for column ordinal %d", i)
+				}
+				colMeta := rgMeta.Columns[i]
+				if idxLoc != nil {
+					if colIndex {
+						colMeta.ColumnIndexOffset = &idxLoc.Offset
+						colMeta.ColumnIndexLength = &idxLoc.Length
+					} else {
+						colMeta.OffsetIndexOffset = &idxLoc.Offset
+						colMeta.OffsetIndexLength = &idxLoc.Length
+					}
+				}
+			}
+		}
+		return nil
+	}
+
+	for rgOrdinal := range f.rowGroups {
+		if err := setIndexLoc(int64(rgOrdinal), loc.ColIndexLocation, true); err != nil {
+			return err
+		}
+		if err := setIndexLoc(int64(rgOrdinal), loc.OffsetIndexLocation, false); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
 // Clears out this filemetadatabuilder so it can be re-used
 func (f *FileMetaDataBuilder) Clear() {
 	f.metadata = format.NewFileMetaData()
@@ -243,6 +286,10 @@ type FileMetaData struct {
 	// size of the raw bytes of the metadata in the file which were
 	// decoded by thrift, Size() getter returns the value.
 	metadataLen int
+
+	// sourceFileSize is not a part of FileMetaData, but it is mainly used to parse meta data.
+	// Users can manually set this value and they are responsible for the validity of it.
+	sourceFileSize int64
 }
 
 // NewFileMetaData takes in the raw bytes of the serialized metadata to deserialize
@@ -275,6 +322,12 @@ func NewFileMetaData(data []byte, fileDecryptor encryption.FileDecryptor) (*File
 // Size is the length of the raw serialized metadata bytes in the footer
 func (f *FileMetaData) Size() int { return f.metadataLen }
 
+// GetSourceFileSize get the total size of the source file from meta data.
+func (f *FileMetaData) GetSourceFileSize() int64 { return f.sourceFileSize }
+
+// SetSourceFileSize set the total size of the source file in meta data.
+func (f *FileMetaData) SetSourceFileSize(sourceFileSize int64) { f.sourceFileSize = sourceFileSize }
+
 // NumSchemaElements is the length of the flattened schema list in the thrift
 func (f *FileMetaData) NumSchemaElements() int {
 	return len(f.FileMetaData.Schema)
@@ -322,7 +375,7 @@ func (f *FileMetaData) initColumnOrders() {
 				orders = append(orders, parquet.ColumnOrders.Undefined)
 			}
 		}
-	} else {
+	} else if f.Schema.NumColumns() > 0 {
 		orders = orders[:f.Schema.NumColumns()]
 		orders[0] = parquet.ColumnOrders.Undefined
 		for i := 1; i < len(orders); i *= 2 {
@@ -388,6 +441,7 @@ func (f *FileMetaData) Subset(rowGroups []int) (*FileMetaData, error) {
 		f.FileDecryptor,
 		f.version,
 		0,
+		f.sourceFileSize,
 	}
 
 	out.RowGroups = make([]*format.RowGroup, 0, len(rowGroups))
@@ -428,7 +482,7 @@ func (f *FileMetaData) VerifySignature(signature []byte) bool {
 	var buf bytes.Buffer
 	buf.Grow(enc.CiphertextSizeDelta() + len(data))
 	encryptedLen := enc.SignedFooterEncrypt(&buf, data, []byte(key), []byte(aad), nonce)
-	return bytes.Equal(buf.Bytes()[encryptedLen-encryption.GcmTagLength:], tag)
+	return subtle.ConstantTimeCompare(buf.Bytes()[encryptedLen-encryption.GcmTagLength:], tag) == 1
 }
 
 // WriteTo will serialize and write out this file metadata, encrypting it if
@@ -489,6 +543,9 @@ func (f *FileMetaData) Version() parquet.Version {
 	}
 }
 
+func (f *FileMetaData) NumRowGroups() int { return len(f.RowGroups) }
+func (f *FileMetaData) NumColumns() int   { return f.Schema.NumColumns() }
+
 // FileCryptoMetadata is a proxy for the thrift fileCryptoMetadata object
 type FileCryptoMetadata struct {
 	metadata          *format.FileCryptoMetaData
